@@ -13,7 +13,9 @@ import requests
 
 from metapack.cli.core import MetapackCliMemo as _MetapackCliMemo
 from metapack.package import Downloader
-from metapack.support import pylib
+from metapack_build.support import pylib
+
+from .update import add_missing_files
 
 downloader = Downloader.get_instance()
 
@@ -108,10 +110,9 @@ def new_cmd(args):
     from metapack import MetapackDoc
     from metapack.util import make_metatab_file, datetime_now, ensure_dir
     from metapack.cli.core import write_doc, prt, err
-    from os.path import exists, join, expanduser, dirname
+    from os.path import exists, join, expanduser
     from metatab import DEFAULT_METATAB_FILE
     from os import getenv
-    import metapack.support as support_dir
 
     if args.config:
         config_file = args.config
@@ -234,11 +235,7 @@ def new_cmd(args):
 
             write_doc(doc, join(nv_name, DEFAULT_METATAB_FILE))
 
-            with open(join(dirname(support_dir.__file__), 'gitignore')) as f:
-                gitignore = f.read()
-
-            with open(join(nv_name, '.gitignore'), 'w') as f:
-                f.write(gitignore)
+            add_missing_files(nv_name)
 
             if args.title:
                 readme = '# {}\n'.format(args.title)
